:: General note on .BAT file:
:: - lines beginning with "::" are comments and are also used to disable unused code.
:: - lines beginning with ":" are labels for goto statement, used to to skip blocs.

:: Cet outil, basé sur l'emploi de sed et d'un fichier de paramètres de remplacement,
:: permet de créer à partir d'un fichier tra incluant les textes traduits de BG2EE
:: l'extrait de fichier tph qui installe les textes dans le jeu.
:: Le script est conçu pour l'organisation suivante :
:: répertoire de départ
:: + francais (répertoire)
::   - traduction.tra : fichier tra contenant les textes traduits au format .tra
:: - creeSTRING_SET_TPH.sed : instructions sed pour constituer les commandes STRING_SET pour le fichier tph
:: - Documentation.txt
:: - MakeTPH.bat : script de lancement du traitement
:: - remplace_NUM_TPH.sed : instructions sed pour remplacer 
:: - ssed.exe : programme "super" sed permettant les transformations de texte
:: - weidu.exe : programme servant au traitement initial du fichier tra

:: Le script va chercher le fichier traduction.tra dans le sous-répertoire francais
:: et crée le fichier tph dans le répertoire de départ.
:: Il a besoin des fichiers creeSTRING_SET_TPH.sed et remplace_Num_TPH.sed à ses côtés.
:: Le script a besoin de ssed.exe et weidu.exe pour fonctionner, dans le même répertoire que ce fichier.
:: Les fichiers temporaires sont supprimés à la fin.

:: Historique
:: 29/01/2017 - V1
:: 13/05/2017 - V2 - mise au propre et ajout d'explications

@echo off

:: Verifie la présence du sous-répertoire francais
if not exist francais goto francais_absent
if not exist francais\traduction.tra goto francais_absent

:: Effacement du fichier final, s'il existe
if exist traduction.tph del traduction.tph

:: Pour ne pas toujours répéter le début (mise au point)
::goto phaseSedApresTraify

:: On veut se débarrasser des textes du fichier traduction.tra pour ne manipuler que les numéros,
:: afin de créer les instructions du fichier tp2. Comme sed ne dispose de la capacité de traiter
:: les textes sur plusieurs lignes, on constitue un fichier tp2 dont weidu saura extraire les textes
:: pour nous.
:: La fonction --traify de WeiDU va nous y aider, mais à condition qu'on ait un vrai fichier tp2,
:: donc avec des instructions particulières au début.

if exist bg2eefrtmp.tp2 del /F bg2eefrtmp.tp2

@echo // Partie provisoire pour conversion : a ne pas conserver ou a modifier >> bg2eefrtmp.tp2
@echo BACKUP ~bgeefrcorrec/backup~ >> bg2eefrtmp.tp2
@echo AUTHOR ~Isaya~ >> bg2eefrtmp.tp2
@echo README ~bgeefrcorrec/Lisez-moi.txt~ >> bg2eefrtmp.tp2
@echo LANGUAGE ~Francais~ >> bg2eefrtmp.tp2
@echo     ~francais~ >> bg2eefrtmp.tp2
@echo     ~bgeefrcorrec/francais/setup.tra~ >> bg2eefrtmp.tp2
@echo     ~bgeefrcorrec/francais/bgeefrcorrec.tra~ >> bg2eefrtmp.tp2
@echo BEGIN @1000000000 >> bg2eefrtmp.tp2
@echo // Fin de partie provisoire pour conversion >> bg2eefrtmp.tp2
:: Nota : pas de ligne VERSION car WeiDU le traifie
::@echo VERSION ~v n'importe quoi~ >> bg2eefrtmp.tp2

:: Copie du fichier tra dans le fichier tp2
more francais\traduction.tra >> bg2eefrtmp.tp2

:phaseSedAvantTraify

:: Edition des lignes @10nnnnn = ~texte~ ... recopiées du fichier tra sous une forme correcte pour un fichier tp2
:: STRING_SET @nnnnn ~texte~ ~féminin~

@echo Extraction des numeros de texte concernes dans le fichier tp2
ssed -f creeSTRING_SET_TPH.sed bg2eefrtmp.tp2 > vrai_tp2.tp2
if errorlevel 1 goto echec_num_textes

:: Fichier intermédiaire désormais inutile
del /F bg2eefrtmp.tp2

:: Extraction des textes du fichier tp2 dans un fichier tra : le but est d'obtenir un tp2 sous la forme
:: STRING_SET ~nnn~ @mmm
:: Comme WeiDU attribue les numéros mmm à partir de 0, ces numéros de textes ne correspondent pas
:: à ceux du fichier tra de bg2eefr, donc on jettera le fichier tra obtenu

@echo Traify par WeiDU du fichier tp2 (suppression des textes) : veuillez patienter
weidu --nogame --traify vrai_tp2.tp2 --out vrai_tp2_tra

if errorlevel 1 goto echec_traify
:: Fichiers intermédiaires inutiles désormais
del /F vrai_tp2_tra.tra
del /F vrai_tp2.tp2

:phaseSedApresTraify

:: Modification du fichier tp2 pour qu'il ait la forme qui nous intéresse, avec les bons numéros de textes
:: STRING_SET nnnnn @nnnnn

@echo Mise a jour des bons numeros de texte dans le fichier tp2

ssed -f remplace_Num_TPH.sed vrai_tp2_tra.tp2 > traduction.tph
if errorlevel 1 goto echec_restauration_num

:: Fichier intermédiaire inutile désormais
del /F vrai_tp2_tra.tp2

:: L'extrait de fichier tp2 est créé. Il reste maintenant recopier la partie utile
:: (les STRING_SET) dans le fichier tph correspondant.

@echo Le fichier traduction.tph est cree

goto end

:francais_absent
@echo Le fichier francais\traduction.tra est absent : opération impossible

goto end

:echec_num_textes
@echo Echec de la transformation en fichier tp2

goto end

:echec_traify
@echo Echec de la traification du fichier tp2

goto end

:echec_restauration_num
@echo Echec de la restauration des bons numeros de texte

goto end

:end
pause
